@@ -1,6 +1,7 @@
 from flask import current_app as app
 from . import routes
 
+
 @routes.route('/versions')
 def library_versions():
     import pkg_resources
@@ -9,7 +10,7 @@ def library_versions():
     for name in app.smartglass_packetnames:
         try:
             versions[name] = pkg_resources.get_distribution(name).version
-        except:
+        except Exception:
             versions[name] = None
 
     return app.success(versions=versions)
